#
# spec file for package php5-pear-MDB2
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-MDB2
%define pear_name  MDB2
%define pear_sname mdb2
Summary:        Database abstraction layer
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Version:        2.5.0b5
Release:        19.1%{?dist}.kolab_3.4
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         %{pear_name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 5.2.0
%if 0%{?sles_version} == 10
BuildRequires:  php-macros
%else
BuildRequires:  php-devel >= 5.2.0
%endif
BuildRequires:  php-pear >= 1.9.1
Requires:       php >= 5.2.0
Requires:       php-pear >= 1.9.1

Provides:       php-pear-%{pear_name} pear-%{pear_name}
# Fix for renaming (package convention)
Provides:       php5-pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php-pear(%{pear_name}) = %{version}
Provides:       pear-%{pear_sname} = %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      pear-%{pear_sname} < %{version}

%description
PEAR MDB2 is a merge of the PEAR DB and Metabase php database abstraction layers.

It provides a common API for all supported RDBMS. The main difference to most
other DB abstraction packages is that MDB2 goes much further to ensure
portability. MDB2 provides most of its many features optionally that
can be used to construct portable SQL statements:
* Object-Oriented API
* A DSN (data source name) or array format for specifying database servers
* Datatype abstraction and on demand datatype conversion
* Various optional fetch modes to fix portability issues
* Portable error codes
* Sequential and non sequential row fetching as well as bulk fetching
* Ability to make buffered and unbuffered queries
* Ordered array and associative array for the fetched rows
* Prepare/execute (bind) named and unnamed placeholder emulation
* Sequence/autoincrement emulation
* Replace emulation
* Limited sub select emulation
* Row limit emulation
* Transactions/savepoint support
* Large Object support
* Index/Unique Key/Primary Key support
* Pattern matching abstraction
* Module framework to load advanced functionality on demand
* Ability to read the information schema
* RDBMS management methods (creating, dropping, altering)
* Reverse engineering schemas from an existing database
* SQL function call abstraction
* Full integration into the PEAR Framework
* PHPDoc API documentation

%prep
%setup -c

# patch autoload.inc to not include buildroot
sed -i -e '17s/@php_dir@/\/usr\/share\/php5\/PEAR/' MDB2-2.5.0b5/tests/autoload.inc
sed -i -e '21s/@php_dir@/\/usr\/share\/php5\/PEAR/' MDB2-2.5.0b5/tests/autoload.inc

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
        -d doc_dir=/doc \
        -d bin_dir=%{_bindir} \
        -d data_dir=%{php_peardir}/data \
        install --offline --nodeps -R "%{buildroot}" package.xml

%{__install} -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf %{buildroot}/{doc,tmp}
%{__rm} -rf %{buildroot}%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}
# remove data, LICENSE to docdir
%{__rm} -rf $RPM_BUILD_ROOT/%{php_peardir}/data

cd ..

%php_pear_gen_filelist

%post
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml
fi

%postun
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)
%doc %{pear_name}-%{version}/LICENSE
%doc %{pear_name}-%{version}/docs/*

%changelog
* Fri Feb  1 2013 aj@ajaissle.de
- New upstream release 2.5.0b5
- Changelog 2.5.0b5
  * fixed bug #18494: _compareIntegerDefinition() ignores length
    change.
  * fixed bug #16280: compareDefinition() turns NULL defaults into
    empty strings for NOT NULL columns.
  * fixed bug #19677: Call to undefined function: MDB2_Driver
    mysql::isError()
- Changelog 2.5.0b4
  * MDB2 is now E_STRICT compliant! [danielc]
  * Fix Bug #9502: Strong typing query result misbehaves [danielc]
  * Fix Bug #16508: mdb2-2.5.0b1 not working with PHP 5.3.0
    [quipo]
  * Fix Bug #17552: MDB2_Driver_Manager
    ibase::listTableConstraints returns list of indices [quipo]
  * Fix Bug #17890: Improper use of array_search in psgsql.php
    v1.173 prepare function [quipo]
  * Fix Bug #18050: Many &quot;Deprecated&quot; [quipo]
  * Fix Bug #18175: Using MDB2::factory raises fatal error [quipo]
  * Fix Bug #18203: Type introspection breaks with associative
    arrays if names are identical [danielc] (patch by Peter Bex)
  * Fix Bug #18398: non-static functions called statically
    [danielc]
  * Fix Bug #18427: Notices appear while debugging [quipo]
  * Fix Bug #18721: DSN URLs do not support &quot;@&quot; in
    database names [danielc]
  * Fix Bug #18826: Crash and security problem with is_a() in
    combination with value escaping [doconnor]
  * Fix Bug #18886: Deprecated code generates warnings
    [astembridge]
  * Fix Bug #18978: upgrade from alpha2 to beta3 breaks
    iterator.php [danielc]
  * Fix Bug #19008: remove error_reporting (for PEAR QA team)
    [danielc]
  * Fix Bug #19136: Infinite Recurcsion makes result object
    unuseable [danielc]
  * Fix Bug #19148: &quot;undefined variable result&quot; in
    MDB2_Driver_Common::_wrapQuery() [danielc]
  * Fix Bug #19191: Have dropSequence() return MDB2_OK on success,
    as documented [danielc]
  * Fix Bug #19192: Have createSequence() return MDB2_OK on
    success, as documented [danielc]
  * Fix Bug #19193: Have createConstraint() return MDB2_OK on
    success, as documented [danielc]
  * Fix Bug #19194: Have dropConstraint() return MDB2_OK on
    success, as documented [danielc]
  * Fix Bug #19195: Have createIndex() return MDB2_OK on success,
    as documented [danielc]
  * Fix Bug #19196: Have vacuum() return MDB2_OK on success, as
    documented [danielc]
  * Fix Bug #19199: Have dropTable() return MDB2_OK on success,
    as documented [danielc]
  * Fix Bug #19200: Have alterTable() return MDB2_OK on success,
    as documented [danielc]
  * Fix Bug #19201: Have truncateTable() return MDB2_OK on
    success, as documented [danielc]
  * Fix Bug #19202: sqlite foreign key violations produce generic
    MDB2_ERROR [danielc]
  * Fix Bug #19262: Fetchmode constants WERE bitwise [gauthierm]
  * Implement Feature #17367: Documentation Sync Drift [quipo]
  * Implement Feature #18759: User note that is a documentation
    problem [danielc]
  * small performance tweaks
- Changelog 2.5.0b3
  * fixed bug #15912: MDB2::loadClass can return MDB2_OK without
    loading class
  * fixed bug #16020: unable to set params via dsn string in
    parseDSN()
  * fixed bug #16508: reusing var name + return by ref [rix0r]
  * fixed bug #16727: quote(url, 'clob')) fetches URL even if lob
    allow_url_include option is false
  * fixed unreported bug in parseDSN() and oracle's Easy Connect
    syntax
  * fixed bug #16973 and #17039: Wrong _skipDelimitedStrings
    behavior with escaped quotes
  * fixed bug #16994: incompatible declaration of
    setTransactionIsolation() in some drivers
  * dropped PHP 4 support
  * PHP 5.3 compatibility fixes
  * performance tweaks (reduced number of internal function calls)
  * added new sqlsrv driver (native SQL Server driver) [Chris
    Pucci, Mike Ketcham]
  * added new ODBC experimental driver [pschellhaas]
  * Switched test suite to PHPUnit 3.5
- Changelog 2.5.0b2
  * fixed bug #12117: disconnect() does not work as documented
  * fixed bug #12912: replace() documentation
  * fixed bug #13811: _skipDelimitedStrings() fails on empty
    strings
  * fixed bug #13898: more tolerant check for 'new_link' DSN option
  * request #13929: added 'default_fk_action_ondelete' and
    'default_fk_action_onupdate' options for default FOREIGN KEY
    constraints actions
  * fixed bug #14124: _skipDelimitedStrings() and prepare() fail
    with sql comments inside quoted strings
  * fixed bug #14179: declaration of MDB2_Driver
    Common::raiseError() must be compatible with that of
    PEAR::raiseError()
  * fixed doc bug #14290: connect should mention the type of
    object returned
  * fixed bug #14831: $ignores in _skipDelimitedStrings()
    [patch by Aleksander Machniak]
- Changelog 2.5.0b1
  * request #12731: added truncateTable() in the Manager module
  * request #12732: added vacuum() in the Manager module for
    OPTIMIZE/VACUUM TABLE abstraction
  * request #12800: added alterDatabase() in the Manager module
    [afz]
  * fixed bug #12924: correctly handle internal expected errors
    even with custom error handling
  * fixed bug #12991: new error code in errorInfo() [afz]
  * added databaseExists() method [afz]
  * request #13106: added unixtimestamp() in the Function module
  * added max_identifiers_length option
- Changelog 2.5.0.a2
  * fixed bug #12358: E_STRICT changes in latest alpha broke PHP4
    compatibility
  * fixed bug #12351: wrong case for function PEAR::isError() in
    the Reverse module [was: IsError()]
  * fixed bug #12530: MDB2_Extended::autoPrepare() gives error if
    $types is null
  * request #12012: added charset/collation support in
    createDatabase() for the drivers that support this feature
  * added bindname_format option (this is the regexp used to
    recognize named placeholders in prepared statements)
- Changelog 2.5.0a1
  * fixed bug #10024: Security fix for LOBs. Added an option to
    turn lob_allow_url_include off by default
  * fixed bug #11179: prepared statements with named placeholders
    fail if extra values are provided
  * request #11297: added support for "schema.table" (or
    "owner.table") notation in the Reverse module
  * initial support for FOREIGN KEY and CHECK constraints in the
    Reverse and Manager modules
  * fixed bug #11428: propagate quote() errors with invalid data
    types
  * added new test cases in the test suite
  * added LENGTH() function in the Function module
  * fixed bug #11612: raiseError() must be compatible with
    PEAR::raiseError() [PHP6]
  * fixed bug #11790: avoid array_diff() because it has a memory
    leak in PHP 5.1.x
  * fixed bug #11906: quoteIdentifier fails for names with dots
  * fixed bug #11975: Extended::autoExecute() does not work with
    Oracle when using LOBs (patch by Pieter Meulen, van der)
  * fixed some E_STRICT errors with PHP5
  * fixed bug #12083: createTable() in the Manager module now
    returns MDB2_OK on success, as documented
  * fixed bug #12246: wrong check in MDB2::isStatement() (thanks to
    zaa@zaa.pp.ru)
* Fri Feb  1 2013 aj@ajaissle.de
-  improved spec file to serve more build targets
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- adapted packaging for SLE11SP2 compatibility
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- package rename php5-pear-MDB2
- added php-macros
- cleanup spec
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- new version 2.4.1
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
